pub fn get_account_balance<D: Database>(
state: &mut State<D>,
addr: Address,
) -> U256Expand description
Reads the balance of an account from the state.
pub fn get_account_balance<D: Database>(
state: &mut State<D>,
addr: Address,
) -> U256Reads the balance of an account from the state.