pub fn read_storage_at<D: Database>(
state: &mut State<D>,
account: Address,
slot: U256,
) -> U256Expand description
Reads a storage slot from an arbitrary account, checking cache -> bundle -> database.
pub fn read_storage_at<D: Database>(
state: &mut State<D>,
account: Address,
slot: U256,
) -> U256Reads a storage slot from an arbitrary account, checking cache -> bundle -> database.