pub fn set_account_code<D: Database>(
state: &mut State<D>,
addr: Address,
code: Bytes,
)Expand description
Sets the code of an account, loading it into cache if needed.
pub fn set_account_code<D: Database>(
state: &mut State<D>,
addr: Address,
code: Bytes,
)Sets the code of an account, loading it into cache if needed.