pub fn write_storage_at<D: Database>(
state: &mut State<D>,
account: Address,
slot: U256,
value: U256,
)Expand description
Writes a storage slot to an arbitrary account using the transition mechanism.
pub fn write_storage_at<D: Database>(
state: &mut State<D>,
account: Address,
slot: U256,
value: U256,
)Writes a storage slot to an arbitrary account using the transition mechanism.