pub struct Storage<D> {
pub state: *mut State<D>,
pub base_key: B256,
pub account: Address,
}Expand description
Hierarchical storage abstraction over EVM account state.
State lives in a specific account. Storage uses keccak256-based subspace derivation to create a hierarchical key space.
Fields
state: *mut State<D>base_key: B256account: AddressImplementations
Sourceimpl<D: Database> Storage<D>
impl<D: Database> Storage<D>
Sourcepub fn new(state: *mut State<D>, base_key: B256) -> Self
pub fn new(state: *mut State<D>, base_key: B256) -> Self
Creates a new Storage backed by the ArbOS state account.
Sourcepub fn new_with_account(
state: *mut State<D>,
base_key: B256,
account: Address,
) -> Self
pub fn new_with_account( state: *mut State<D>, base_key: B256, account: Address, ) -> Self
Creates a new Storage backed by a specific account.
Sourcepub fn open_sub_storage(&self, sub_key: &[u8]) -> Storage<D>
pub fn open_sub_storage(&self, sub_key: &[u8]) -> Storage<D>
Opens a child subspace by hashing the parent key with the child ID.
Sourcepub fn get_by_uint64(&self, offset: u64) -> Result<B256, ()>
pub fn get_by_uint64(&self, offset: u64) -> Result<B256, ()>
Reads a 32-byte value by uint64 offset.
Sourcepub fn set_by_uint64(&self, offset: u64, value: B256) -> Result<(), ()>
pub fn set_by_uint64(&self, offset: u64, value: B256) -> Result<(), ()>
Writes a 32-byte value by uint64 offset.
Sourcepub fn get_uint64_by_uint64(&self, offset: u64) -> Result<u64, ()>
pub fn get_uint64_by_uint64(&self, offset: u64) -> Result<u64, ()>
Reads a U256 by uint64 offset.
Sourcepub fn set_uint64_by_uint64(&self, offset: u64, value: u64) -> Result<(), ()>
pub fn set_uint64_by_uint64(&self, offset: u64, value: u64) -> Result<(), ()>
Writes a U256 by uint64 offset.
Sourcepub fn get(&self, key: B256) -> Result<B256, ()>
pub fn get(&self, key: B256) -> Result<B256, ()>
Reads a 32-byte value by B256 key using mapAddress algorithm.
Sourcepub fn set(&self, key: B256, value: B256) -> Result<(), ()>
pub fn set(&self, key: B256, value: B256) -> Result<(), ()>
Writes a 32-byte value by B256 key using mapAddress algorithm.